package com.ruoyi.supplier.service;

import java.util.List;
import com.ruoyi.supplier.domain.TCanteenDaily;

/**
 * 供应商日常工作记录Service接口
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
public interface ITCanteenDailyService 
{
    /**
     * 查询供应商日常工作记录
     * 
     * @param dailyId 供应商日常工作记录主键
     * @return 供应商日常工作记录
     */
    public TCanteenDaily selectTCanteenDailyByDailyId(Long dailyId);

    /**
     * 查询供应商日常工作记录列表
     * 
     * @param tCanteenDaily 供应商日常工作记录
     * @return 供应商日常工作记录集合
     */
    public List<TCanteenDaily> selectTCanteenDailyList(TCanteenDaily tCanteenDaily);

    /**
     * 新增供应商日常工作记录
     * 
     * @param tCanteenDaily 供应商日常工作记录
     * @return 结果
     */
    public int insertTCanteenDaily(TCanteenDaily tCanteenDaily);

    /**
     * 修改供应商日常工作记录
     * 
     * @param tCanteenDaily 供应商日常工作记录
     * @return 结果
     */
    public int updateTCanteenDaily(TCanteenDaily tCanteenDaily);

    /**
     * 批量删除供应商日常工作记录
     * 
     * @param dailyIds 需要删除的供应商日常工作记录主键集合
     * @return 结果
     */
    public int deleteTCanteenDailyByDailyIds(Long[] dailyIds);

    /**
     * 删除供应商日常工作记录信息
     * 
     * @param dailyId 供应商日常工作记录主键
     * @return 结果
     */
    public int deleteTCanteenDailyByDailyId(Long dailyId);
}
